summaryrefslogtreecommitdiffstats
path: root/kshowmail/kfeedback.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-07-24 15:59:03 -0500
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-07-24 15:59:03 -0500
commit9c02dbb59ce57c68dc177d9294b980bf114a3e11 (patch)
treeb1b40423c9be9a42a97cd0e8f3af3139aefb6fa0 /kshowmail/kfeedback.h
parent0b875800e452c97b1a3f25aba5f029a8c33a4b93 (diff)
downloadkshowmail-9c02dbb59ce57c68dc177d9294b980bf114a3e11.tar.gz
kshowmail-9c02dbb59ce57c68dc177d9294b980bf114a3e11.zip
Update to TDE R14 API
Diffstat (limited to 'kshowmail/kfeedback.h')
-rw-r--r--kshowmail/kfeedback.h90
1 files changed, 45 insertions, 45 deletions
diff --git a/kshowmail/kfeedback.h b/kshowmail/kfeedback.h
index 620ace7..10c0633 100644
--- a/kshowmail/kfeedback.h
+++ b/kshowmail/kfeedback.h
@@ -18,8 +18,8 @@
#include <config.h>
#endif
-#include <qlistview.h>
-#include <qvbox.h>
+#include <ntqlistview.h>
+#include <ntqvbox.h>
#include <kdialogbase.h>
@@ -32,7 +32,7 @@ class KFeedbackForm;
class KFeedbackQuestionList;
class KFeedbackQuestion;
class KFeedbackAnswer;
-class QMultiLineEdit;
+class TQMultiLineEdit;
/**
@@ -48,8 +48,8 @@ public:
/**
* Constructor.
**/
- KFeedbackDialog( const QString & feedbackMailAddress,
- const QString & helpTopic = QString::null );
+ KFeedbackDialog( const TQString & feedbackMailAddress,
+ const TQString & helpTopic = TQString::null );
/**
@@ -95,7 +95,7 @@ protected:
* User is asked a list of questions, the answers of which will be sent via
* mail back to a feedback mail address.
**/
-class KFeedbackForm: public QVBox
+class KFeedbackForm: public TQVBox
{
Q_OBJECT
@@ -103,8 +103,8 @@ public:
/**
* Constructor.
**/
- KFeedbackForm( const QString & feedbackMailAddress,
- QWidget * parent );
+ KFeedbackForm( const TQString & feedbackMailAddress,
+ TQWidget * parent );
/**
* Destructor.
@@ -171,20 +171,20 @@ protected:
/**
* Format the "personal comments" field for sending mail.
**/
- QString formatComment();
+ TQString formatComment();
- QString _feedbackMailAddress;
+ TQString _feedbackMailAddress;
KFeedbackQuestionList * _questionList;
- QMultiLineEdit * _comment;
+ TQMultiLineEdit * _comment;
};
/**
* List of feedback questions presented in a @ref QListView widget.
**/
-class KFeedbackQuestionList: public QListView
+class KFeedbackQuestionList: public TQListView
{
Q_OBJECT
@@ -193,7 +193,7 @@ public:
/**
* Constructor.
**/
- KFeedbackQuestionList( QWidget *parent );
+ KFeedbackQuestionList( TQWidget *parent );
/**
* Destructor.
@@ -209,7 +209,7 @@ public:
/**
* The result of all answered questions in ASCII.
**/
- QString result();
+ TQString result();
/**
* Add a yes/no question to the list.
@@ -228,16 +228,16 @@ public:
* Returns a pointer to this question so you can add answers.
**/
- KFeedbackQuestion * addQuestion( const QString & text,
- const QString & id,
+ KFeedbackQuestion * addQuestion( const TQString & text,
+ const TQString & id,
bool exclusiveAnswer = true,
bool required = false );
/**
* Add a yes/no question to the list.
**/
- void addYesNoQuestion( const QString & text,
- const QString & id,
+ void addYesNoQuestion( const TQString & text,
+ const TQString & id,
bool required = false );
/**
@@ -245,7 +245,7 @@ public:
* Use @ref KFeedbackQuestion::next() to get the next one.
**/
KFeedbackQuestion * firstQuestion() const
- { return (KFeedbackQuestion *) QListView::firstChild(); }
+ { return (KFeedbackQuestion *) TQListView::firstChild(); }
/**
* Notify the list that another question has been answered.
@@ -272,7 +272,7 @@ signals:
/**
* A user feedback question to be inserted into a @ref KFeedbackQuestionList.
**/
-class KFeedbackQuestion: public QCheckListItem
+class KFeedbackQuestion: public TQCheckListItem
{
public:
@@ -298,8 +298,8 @@ public:
* checked at any one time, to 'false' if multiple answers are allowed.
**/
KFeedbackQuestion( KFeedbackQuestionList * parent,
- const QString & text,
- const QString & id,
+ const TQString & text,
+ const TQString & id,
bool exclusiveAnswer = true,
bool required = false,
bool open = true );
@@ -310,8 +310,8 @@ public:
* the mail. The answer IDs need only be unique for that question; answers
* to other questions may have the same ID.
**/
- void addAnswer( const QString & text,
- const QString & id );
+ void addAnswer( const TQString & text,
+ const TQString & id );
/**
* Returns if answering this question is required.
@@ -331,17 +331,17 @@ public:
* features_i_like="pink_elephant"
* features_i_like="studlycapslyfier"
**/
- QString result();
+ TQString result();
/**
* Return this question's ID.
**/
- QString id() { return _id; }
+ TQString id() { return _id; }
/**
* Return this question's text.
**/
- QString text();
+ TQString text();
/**
* Returns whether or not this question requires an exclusive answer.
@@ -352,22 +352,22 @@ public:
/**
* Returns the sort key.
*
* Reimplemented from @ref QListViewItem to maintain insertion order.
**/
- virtual QString key( int column, bool ascending ) const;
+ virtual TQString key( int column, bool ascending ) const;
/**
* Returns the next question or 0 if there is no more.
**/
KFeedbackQuestion * nextQuestion() const
- { return (KFeedbackQuestion *) QListViewItem::nextSibling(); }
+ { return (KFeedbackQuestion *) TQListViewItem::nextSibling(); }
/**
* Returns the first possible answer to this question.
* Use @ref KFeedbackAnswer::nextAnswer() to get the next one.
**/
KFeedbackAnswer * firstAnswer() const
- { return (KFeedbackAnswer *) QListViewItem::firstChild(); }
+ { return (KFeedbackAnswer *) TQListViewItem::firstChild(); }
/**
* Returns the @ref KFeedbackQuestionList this question belongs to or 0 if
@@ -378,14 +378,14 @@ public:
protected:
- QString _id;
+ TQString _id;
bool _exclusiveAnswer;
bool _required;
int _no;
};
-class KFeedbackAnswer: public QCheckListItem
+class KFeedbackAnswer: public TQCheckListItem
{
public:
/**
@@ -395,19 +395,19 @@ public:
* of many.
**/
KFeedbackAnswer( KFeedbackQuestion * parent,
- const QString & text,
- const QString & id,
+ const TQString & text,
+ const TQString & id,
bool exclusive = true );
/**
* Return this answer's ID.
**/
- QString id() { return _id; }
+ TQString id() { return _id; }
/**
* Return this answer's text.
**/
- QString text();
+ TQString text();
/**
* Returns whether or not this is an exclusive answer.
@@ -417,32 +417,32 @@ public:
/**
* Returns whether or not this answer is checked.
**/
- bool isChecked() { return QCheckListItem::isOn(); }
+ bool isChecked() { return TQCheckListItem::isOn(); }
/**
* Returns the next possible answer or 0 if there is no more.
**/
KFeedbackAnswer * nextAnswer() const
- { return (KFeedbackAnswer *) QListViewItem::nextSibling(); }
+ { return (KFeedbackAnswer *) TQListViewItem::nextSibling(); }
/**
* Returns the question to this answer.
**/
KFeedbackQuestion * question() const
- { return (KFeedbackQuestion *) QListViewItem::parent(); }
+ { return (KFeedbackQuestion *) TQListViewItem::parent(); }
/**
* Returns the sort key.
*
* Reimplemented from @ref QListViewItem to maintain insertion order.
**/
- virtual QString key( int column, bool ascending ) const;
+ virtual TQString key( int column, bool ascending ) const;
/**
* On/off change.
*
* Reimplemented from @ref QCheckListItem to monitor answering required
* questions. This method notifies the @ref KFeedbackQuestionList whenever
* a required question is being answered.
**/
@@ -450,7 +450,7 @@ public:
protected:
- QString _id;
+ TQString _id;
bool _exclusive;
int _no;
};
@@ -171,20 +171,20 @@ protected:
};
/**
- * List of feedback questions presented in a @ref QListView widget.
+ * List of feedback questions presented in a @ref TQListView widget.
**/
@@ -352,22 +352,22 @@ public:
* Returns the sort key.
*
- * Reimplemented from @ref QListViewItem to maintain insertion order.
+ * Reimplemented from @ref TQListViewItem to maintain insertion order.
**/
@@ -417,32 +417,32 @@ public:
* Returns the sort key.
*
- * Reimplemented from @ref QListViewItem to maintain insertion order.
+ * Reimplemented from @ref TQListViewItem to maintain insertion order.
**/
@@ -417,32 +417,32 @@ public:
* On/off change.
*
- * Reimplemented from @ref QCheckListItem to monitor answering required
+ * Reimplemented from @ref TQCheckListItem to monitor answering required
* questions. This method notifies the @ref KFeedbackQuestionList whenever
* a required question is being answered.